[![pypi-version]][pypi]

# factors

Generates actuarial factors for premium calculations

## Installation

    $ pip install factors


## Requirements

These dependencies are automatically installed:

    Numpy
    Pandas
    xlrd
    openpyxl


## Example

    >> from factors.examples import example1
    >> example1()


## Changelog
See CHANGELOG.md for the latest changes.

[changelog]: CHANGELOG.md
[pypi-version]: https://img.shields.io/pypi/v/factors.svg
[pypi]: https://pypi.python.org/pypi/factors
